/*
 * Controls a JTD-0801 HDMI Swith/UpScaler via Arduino IR commands by reading current input indicated by the LED input lights
 * Note:  The LED's use an inverse 5v logic. When LED is on Arduino pin can be pulled LOW. 
 * The button to switch inputs uses 3.3v logic. A  NPN transistor is needed to trigger this from the Arduino. See wireing guide for more info. 
 */

#include <IRremote.h>

int recvPin = 11;                                    // Pin IR Reciever is connected to
IRrecv irrecv(recvPin);                              // Makes IR Reciever Object
decode_results results;                              // Holds recieved IR code

#define switcherPin  10                              // Pin connected to button to switch inputs. (Pin is 3.3v, LED's are 5v)
#define vgaPin  5                                   // Pin connected to VGA LED Indicator 
#define hdmi1Pin  4                                 // Pin connected to HDMI 1 LED Indicator 
#define hdmi2Pin  2                                 // Pin connected to HDMI 2 LED Indicator 
#define hdmi3Pin  3                                 // Pin connected to HDMI 3 LED Indicator 
#define av1Pin  6                                   // Pin connected to AV 1 LED Indicator 
#define av2Pin  7                                   // Pin connected to AV 2 LED Indicator 
#define component1Pin  9                            // Pin connected to Component 1(YPbPr) LED Indicator 
#define component2Pin  8                            // Pin connected to Component 2(YPbPr) LED Indicator 


void setup() {

  // Sets pins connected to LED indicators as inputs with a pullup resistor. External resistors may also be used.
  pinMode(vgaPin, INPUT_PULLUP);
  pinMode(hdmi1Pin, INPUT_PULLUP);
  pinMode(hdmi2Pin, INPUT_PULLUP);
  pinMode(hdmi3Pin, INPUT_PULLUP);
  pinMode(av2Pin, INPUT_PULLUP);
  pinMode(av1Pin, INPUT_PULLUP);
  pinMode(component1Pin, INPUT_PULLUP);
  pinMode(component2Pin, INPUT_PULLUP);

  // Sets the pin to connect to the button to switch inputs as an output
  pinMode(switcherPin, OUTPUT);

  irrecv.enableIRIn();                        // Starts the IR receiver
}

void loop() {
  IRSwitcher();                               // Method that reads remote input & corresponding LED indicator
}

void IRSwitcher() {
  if (irrecv.decode(&results)) {                            // If remote code is recieved store the decoded info as results
    switch (results.value)                                  // A switch statment that checks the button pressed on remote based off its corresponding IR code
    {
      case 0x17FD:    // #1 Button. Takes to HDMI 1
        if (digitalRead(hdmi2Pin) == LOW) {                                     // If the HDMI 2 Pin is LOW meaning on
          for (int loopCounter = 0; loopCounter < 7; loopCounter++) {           // Loops however many times neccessary to get to input desired. (HDMI 2)
            buttonPresser();                                                    // Method that mimics a button press
          }
        }
        if (digitalRead(hdmi3Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 6; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 4; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 5; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(vgaPin) == LOW) {                                     // A loop is not needed here as button only needs to be pressed once. 
          buttonPresser();
        }
        if (digitalRead(component1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 2; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 3; loopCounter++) {
            buttonPresser();
          }
        }
        break;                                                                  // Exit the first switch case

      // NEXT CASE

      case 0x117DD:   // #2 Button. Takes to HDMI 2
        if (digitalRead(hdmi1Pin) == LOW) {
          buttonPresser();
        }
        if (digitalRead(hdmi3Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 7; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 5; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 6; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(vgaPin) == LOW) {
          for (int loopCounter = 0; loopCounter < 2; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 3; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 4; loopCounter++) {
            buttonPresser();
          }
        }
        break;

      // NEXT CASE


      case 0x97ED:          // #3 Button. Takes to HDMI 3
        if (digitalRead(hdmi1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 2; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi2Pin) == LOW) {
          buttonPresser();
        }
        if (digitalRead(av1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 6; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 7; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(vgaPin) == LOW) {
          for (int loopCounter = 0; loopCounter < 3; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 4; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 5; loopCounter++) {
            buttonPresser();
          }
        }
        break;

      // NEXT CASE

      case 0x197CD:   // #4 Button. Takes to VGA
        if (digitalRead(hdmi1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 7; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 6; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi3Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 5; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 3; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 4; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component1Pin) == LOW) {
          buttonPresser();
        }
        if (digitalRead(component2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 2; loopCounter++) {
            buttonPresser();
          }
        }
        break;

      // NEXT CASE

      case 0x57F5:      // #5 button. Takes to Component #1
        if (digitalRead(hdmi1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 6; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 5; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi3Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 4; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 2; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 3; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(vgaPin) == LOW) {
          for (int loopCounter = 0; loopCounter < 7; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component2Pin) == LOW) {
          buttonPresser();
        }
        break;

      // NEXT CASE


      case 0x157D5:  // #6 Button. Takes to Component 2
        if (digitalRead(hdmi1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 5; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 4; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi3Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 3; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av1Pin) == LOW) {
          buttonPresser();
        }
        if (digitalRead(av2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 2; loopCounter++) {
            buttonPresser();
           }
        }
        if (digitalRead(vgaPin) == LOW) {
          for (int loopCounter = 0; loopCounter < 6; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 7; loopCounter++) {
            buttonPresser();
          }
        }
        break;

      // NEXT CASE

      case 0xD7E5:    //#7 Button. Takes to AV 1
        if (digitalRead(hdmi1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 4; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 3; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi3Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 2; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(av2Pin) == LOW) {
          buttonPresser();
          
        }
        if (digitalRead(vgaPin) == LOW) {
          for (int loopCounter = 0; loopCounter < 5; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 6; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 7; loopCounter++) {
            buttonPresser();
          }
        }
        break;

      // NEXT CASE

      case 0x1D7C5:     // #8 Button. Takes to AV 2
        if (digitalRead(hdmi1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 3; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 2; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(hdmi3Pin) == LOW) {
          buttonPresser();
        }
        if (digitalRead(av1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 7; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(vgaPin) == LOW) {
          for (int loopCounter = 0; loopCounter < 4; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component1Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 5; loopCounter++) {
            buttonPresser();
          }
        }
        if (digitalRead(component2Pin) == LOW) {
          for (int loopCounter = 0; loopCounter < 6; loopCounter++) {
            buttonPresser();
                     }
        }
        break;

      // NEXT CASE

      case 0x8FEE:                              // Up Button
        buttonPresser();                        // Mimics just a simple button press.
        break;
      case 0x18FCE:                            // Down Button
        buttonPresser();                       // There is no backwards scrolling through inputs so the button does the same as the UP button
        break;
    }

    delay(200);       // Just needed before re-anabling IR reciever
    irrecv.resume();  // Re-enable the IR reciever for the next value
  }
}


void buttonPresser() {                       // Method to mimic a button press of the input switch 
  digitalWrite(switcherPin, HIGH);           // Makes pin HIGH to drive transistor
  delay(200);                                // Need a little break as happens faster then a human could push
  digitalWrite(switcherPin, LOW);            // Makes pin LOW and transistor stops
  delay(600);                                // Delay needed between each press as button can not be held down
}                                             
